@@ -3,12 +3,8 @@
 #' \code{as_survey} can be used to create a \code{tbl_svy} using design information
 #' (\code{\link{as_survey_design}}), replicate weights (\code{\link{as_survey_rep}}),
 #' or a two phase design (\code{\link{as_survey_twophase}}), or an object created by the
-#' survey package. \code{as_survey_} is its standard evaluation counterpart.
+#' survey package.
 #'
-#' There is also limited support for databases using dplyr's \code{tbl_sql}
-#' objects for survey designs and replicate weight surveys.
-#' Not all operations are available for these objects, in particular
-#' two phase designs do not work.
 #' See \code{vignette("databases", package = "dplyr")}
 #' for more information on setting up databases in dplyr.
 #'
@@ -49,10 +45,12 @@
 #' d2pbc <- pbc %>%
 #'   as_survey(id = list(id, id), subset = randomized)
 #'
-#' # as_survey_ uses standard evaluation
+#' # dplyr 0.7 introduced new style of NSE called quosures
+#' # See `vignette("programming", package = "dplyr")` for details
+#' st <- quo(stype)
+#' wt <- quo(pw)
 #' dstrata <- apistrat %>%
-#'   as_survey_(strata = "stype", weights = "pw")
-#'
+#'   as_survey(strata = !!st, weights = !!wt)
 as_survey <- function(.data, ...) {
   UseMethod("as_survey")
 }
@@ -60,14 +58,14 @@ as_survey <- function(.data, ...) {
 #' @export
 #' @rdname as_survey
 as_survey.data.frame <- function(.data, ...) {
-  dots <- lazyeval::lazy_dots(...)
+  dots <- rlang::quos(...)
   if ("repweights" %in% names(dots)) {
     as_survey_rep(.data, ...)
   } else if ("id" %in% names(dots) | "ids" %in% names(dots)) {
     # twophase has a list of 2 groups for id, while regular id is just a
     # set of variables
-    id_expr <- as.character(dots$id$expr)
-    if ("list" %in% id_expr & length(id_expr) == 3) {
+    id_expr <- rlang::f_rhs(dots$id)
+    if (length(id_expr) == 3 && id_expr[[1]] == "list") {
       as_survey_twophase(.data, ...)
     } else {
       as_survey_design(.data, ...)
@@ -79,7 +77,7 @@ as_survey.data.frame <- function(.data, ...) {
 
 #' @export
 #' @rdname as_survey
-as_survey.tbl_sql <- as_survey.data.frame
+as_survey.tbl_lazy <- as_survey.data.frame
 
 #' @export
 #' @rdname as_survey
@@ -88,8 +86,8 @@ as_survey.survey.design2 <- function(.data, ...) {
 }
 
 
-#' @export
 #' @rdname as_survey
+#' @export
 as_survey.svyrep.design <- function(.data, ...) {
   as_tbl_svy(.data)
 }
@@ -100,17 +98,27 @@ as_survey.twophase2 <- function(.data, ...) {
   as_tbl_svy(.data)
 }
 
+#' Deprecated SE versions of main srvyr verbs
+#'
+#' srvyr has updated it's standard evaluation semantics to match dplyr 0.7, so
+#' these underscore functions are no longer required (but are still supported
+#' for backward compatbility reasons). See \code{\link[dplyr]{se-deprecated}} or the
+#' dplyr vignette on programming (\code{vignette("programming", package =
+#' "dplyr")}) for more details.
+#' @name srvyr-se-deprecated
+#' @inheritParams as_survey
 #' @export
-#' @rdname as_survey
 as_survey_ <- function(.data, ...) {
-  dots <- lazyeval::lazy_dots(...)
+  warn_underscored()
+  dots <- rlang::quos(...)
   if ("repweights" %in% names(dots)) {
     as_survey_rep_(.data, ...)
   } else if ("id" %in% names(dots) | "ids" %in% names(dots)) {
     # twophase has a list of 2 groups for id, while regular id is
     # just a set of variables
-    id_expr <- as.character(dots$id$expr)
-    if ("list" %in% id_expr & length(id_expr) == 3) {
+    id_expr <- rlang::f_rhs(dots$id)
+    if(is.character(id_expr)) id_expr <- rlang::parse_expr(id_expr)
+    if (length(id_expr) == 3 && id_expr[[1]] == "list") {
       as_survey_twophase_(.data, ...)
     } else {
       as_survey_design_(.data, ...)
